@@ -1,5 +1,5 @@
 /* apreq.c --- AP-REQ functions.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -319,6 +319,7 @@ shishi_apreq_from_file (Shishi * handle, Shishi_asn1 * apreq,
  * @handle: shishi handle as allocated by shishi_init().
  * @apreq: AP-REQ to add authenticator field to.
  * @etype: encryption type used to encrypt authenticator.
+ * @kvno: version of the key used to encrypt authenticator.
  * @buf: input array with encrypted authenticator.
  * @buflen: size of input array with encrypted authenticator.
  *
@@ -328,12 +329,13 @@ shishi_apreq_from_file (Shishi * handle, Shishi_asn1 * apreq,
  * shishi_apreq_add_authenticator() instead, which calculates the
  * encrypted data and calls this function in one step.
  *
- * Return value:
+ * Return value: Returns SHISHI_OK on success.
  **/
 int
 shishi_apreq_set_authenticator (Shishi * handle,
 				Shishi_asn1 apreq,
-				int32_t etype, const char *buf, size_t buflen)
+				int32_t etype, uint32_t kvno,
+				const char *buf, size_t buflen)
 {
   int res;
 
@@ -342,6 +344,13 @@ shishi_apreq_set_authenticator (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
+  if (kvno == UINT32_MAX)
+    res = shishi_asn1_write (handle, apreq, "authenticator.kvno", NULL, 0);
+  else
+    res = shishi_asn1_write_int32 (handle, apreq, "authenticator.kvno", kvno);
+  if (res != SHISHI_OK)
+    return res;
+
   res = shishi_asn1_write_int32 (handle, apreq, "authenticator.etype", etype);
   if (res != SHISHI_OK)
     return res;
@@ -393,6 +402,7 @@ shishi_apreq_add_authenticator (Shishi * handle,
     }
 
   res = shishi_apreq_set_authenticator (handle, apreq, shishi_key_type (key),
+					shishi_key_version (key),
 					buf, buflen);
 
   return res;
