@@ -1,5 +1,5 @@
 /* as.c --- High level client AS functions
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -59,11 +59,6 @@ shishi_as (Shishi * handle, Shishi_as ** as)
       return SHISHI_ASN1_ERROR;
     }
 
-  /* XXX there are reasons for having padata in AS-REQ */
-  res = shishi_kdcreq_clear_padata (las->handle, las->asreq);
-  if (res != SHISHI_OK)
-    return res;
-
   las->asrep = shishi_asrep (handle);
   if (las->asrep == NULL)
     {
@@ -554,6 +549,8 @@ shishi_as_sendrecv_hint (Shishi_as * as, Shishi_tkts_hint * hint)
 	printf ("Received KRB-ERROR...\n");
       if (VERBOSEASN1 (as->handle))
 	shishi_krberror_print (as->handle, stdout, as->krberror);
+      if (VERBOSEASN1(as->handle))
+	shishi_krberror_pretty_print (as->handle, stdout, as->krberror);
     }
   if (res != SHISHI_OK)
     return res;
