@@ -58,9 +58,15 @@ _shishi_print_armored_data (Shishi * handle,
 
   i = base64_encode_alloc (der, derlen, &b64der);
   if (b64der == NULL && i == 0 && derlen != 0)
-    return SHISHI_BASE64_ERROR;
+    {
+      free (der);
+      return SHISHI_BASE64_ERROR;
+    }
   if (b64der == NULL)
-    return SHISHI_MALLOC_ERROR;
+    {
+      free (der);
+      return SHISHI_MALLOC_ERROR;
+    }
 
   fprintf (fh, HEADERBEG "\n", asn1type);
 
@@ -76,10 +82,11 @@ _shishi_print_armored_data (Shishi * handle,
   if ((i + 1) % 64 != 0)
     fprintf (fh, "\n");
 
-  free (b64der);
-
   fprintf (fh, HEADEREND "\n", asn1type);
 
+  free (b64der);
+  free (der);
+
   return SHISHI_OK;
 }
 
