@@ -1,5 +1,5 @@
 /* init.c --- Initialization functions.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -152,6 +152,9 @@ shishi_done (Shishi * handle)
       shishi_tkts_done (&handle->tkts);
     }
 
+  shishi_principal_default_set (handle, NULL);
+  shishi_tkts_default_file_set (handle, NULL);
+
 #ifdef USE_STARTTLS
   rc = _shishi_tls_done (handle);
   if (rc != SHISHI_OK)
@@ -162,8 +165,6 @@ shishi_done (Shishi * handle)
     free (handle->default_realm);
   if (handle->usercfgfile)
     free (handle->usercfgfile);
-  if (handle->tktsdefaultfile)
-    free (handle->tktsdefaultfile);
   if (handle->hostkeysdefaultfile)
     free (handle->hostkeysdefaultfile);
   if (handle->clientkdcetypes)
@@ -172,6 +173,8 @@ shishi_done (Shishi * handle)
     free (handle->authorizationtypes);
   if (handle->stringprocess)
     free (handle->stringprocess);
+  if (handle->userdirectory)
+    free (handle->userdirectory);
 
   if (handle->asn1)
     shishi_asn1_done (handle, handle->asn1);
