@@ -35,6 +35,7 @@
 #endif
 
 #include <stdbool.h>
+#include <stdint.h>
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -54,9 +55,7 @@
 #include <sys/stat.h>
 #endif
 
-#if HAVE_UNISTD_H
 #include <unistd.h>
-#endif
 
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
