@@ -1,5 +1,5 @@
 /* kdcreq.c --- Key distribution (AS/TGS) request functions.
- * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -1288,10 +1288,90 @@ shishi_kdcreq_add_padata_tgs (Shishi * handle,
   return res;
 }
 
+/**
+ * shishi_kdcreq_add_padata_preauth:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @kdcreq: KDC-REQ to add pre-authentication data to.
+ * @key: Key used to encrypt pre-auth data.
+ *
+ * Add pre-authentication data to KDC-REQ.
+ *
+ * Return value: Returns SHISHI_OK iff successful.
+ **/
+int
+shishi_kdcreq_add_padata_preauth (Shishi * handle,
+				  Shishi_asn1 kdcreq,
+				  Shishi_key *key)
+{
+  char *der, *data;
+  size_t derlen, datalen;
+  Shishi_asn1 pa;
+  struct timespec ts;
+  int rc;
+  Shishi_asn1 ed;
+
+  pa = shishi_asn1_pa_enc_ts_enc (handle);
+  if (!pa)
+    return SHISHI_ASN1_ERROR;
+
+  gettime (&ts);
+
+  rc = shishi_asn1_write (handle, pa, "patimestamp",
+			  shishi_generalize_time (handle, ts.tv_sec),
+			  SHISHI_GENERALIZEDTIME_LENGTH);
+  if (rc != SHISHI_OK)
+    return rc;
+
+  rc = shishi_asn1_write_integer (handle, pa, "pausec", ts.tv_nsec / 1000);
+  if (rc != SHISHI_OK)
+    return rc;
+
+  rc = shishi_asn1_to_der (handle, pa, &der, &derlen);
+  if (rc != SHISHI_OK)
+      return rc;
+
+  rc = shishi_encrypt (handle, key, SHISHI_KEYUSAGE_ASREQ_PA_ENC_TIMESTAMP,
+		       der, derlen, &data, &datalen);
+  free (der);
+  if (rc != SHISHI_OK)
+    return rc;
+
+  ed = shishi_asn1_encrypteddata (handle);
+  if (!ed)
+    return SHISHI_ASN1_ERROR;
+
+  rc = shishi_asn1_write_integer (handle, ed, "etype", shishi_key_type (key));
+  if (rc != SHISHI_OK)
+    return rc;
+
+  rc = shishi_asn1_write (handle, ed, "cipher", data, datalen);
+  if (rc != SHISHI_OK)
+    return rc;
+
+  rc = shishi_asn1_write (handle, ed, "kvno", NULL, 0);
+  if (rc != SHISHI_OK)
+    return rc;
+
+  rc = shishi_asn1_to_der (handle, ed, &der, &derlen);
+  free (data);
+  if (rc != SHISHI_OK)
+    return rc;
+
+  rc = shishi_kdcreq_add_padata (handle, kdcreq, SHISHI_PA_ENC_TIMESTAMP,
+				 der, derlen);
+  free (der);
+  if (rc != SHISHI_OK)
+    return rc;
+
+  return rc;
+}
+
 int
 shishi_kdcreq_build (Shishi * handle, Shishi_asn1 kdcreq)
 {
   int res;
+  size_t n;
+  int msgtype;
 
   if (VERBOSE (handle))
     printf ("Building KDC-REQ...\n");
@@ -1316,5 +1396,22 @@ shishi_kdcreq_build (Shishi * handle, Shishi_asn1 kdcreq)
 	}
     }
 
+  res = shishi_asn1_read_integer (handle, kdcreq, "msg-type", &msgtype);
+  if (res != SHISHI_OK)
+    return res;
+  if (msgtype == SHISHI_MSGTYPE_AS_REQ)
+    {
+      res = shishi_asn1_number_of_elements (handle, kdcreq, "padata", &n);
+      if (res == SHISHI_OK && n == 0)
+	{
+	  res = shishi_kdcreq_clear_padata (handle, kdcreq);
+	  if (res != SHISHI_OK)
+	    {
+	      shishi_error_printf (handle, "Could not write padata\n");
+	      return res;
+	    }
+	}
+    }
+
   return SHISHI_OK;
 }
