@@ -28,7 +28,7 @@ struct Shishi_key
   char *realm;
   int type;
   char value[MAX_KEY_LEN];
-  int version;
+  uint32_t kvno; /* UINT32_MAX means undefined kvno */
 };
 
 /**
@@ -165,27 +165,29 @@ shishi_key_value_set (Shishi_key * key, const char *value)
  * shishi_key_version:
  * @key: structure that holds key information
  *
- * Get the "kvno" (key version) of key.
+ * Get the "kvno" (key version) of key.  It will be UINT32_MAX if the
+ * key is not long-lived.
  *
  * Return value: Returns the version of key ("kvno").
  **/
-int
+uint32_t
 shishi_key_version (Shishi_key * key)
 {
-  return key->version;
+  return key->kvno;
 }
 
 /**
  * shishi_key_version_set:
  * @key: structure that holds key information
- * @version: new version integer.
+ * @kvno: new version integer.
  *
- * Set the version of key ("kvno") in key structure.
+ * Set the version of key ("kvno") in key structure.  Use UINT32_MAX
+ * for non-ptermanent keys.
  **/
 void
-shishi_key_version_set (Shishi_key * key, int version)
+shishi_key_version_set (Shishi_key * key, uint32_t kvno)
 {
-  key->version = version;
+  key->kvno = kvno;
 }
 
 /**
@@ -231,6 +233,7 @@ shishi_key (Shishi * handle, Shishi_key ** key)
   *key = xcalloc (1, sizeof (**key));
 
   (*key)->handle = handle;
+  (*key)->kvno = UINT32_MAX;
 
   return SHISHI_OK;
 }
