@@ -1,5 +1,5 @@
 /* shisa.c --- Command line interface to Shishi database.
- * Copyright (C) 2003, 2004  Simon Josefsson
+ * Copyright (C) 2003, 2004, 2006  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -41,7 +41,7 @@
 #define N_(String) gettext_noop (String)
 
 /* Get asprintf. */
-#include "vasprintf.h"
+#include "xvasprintf.h"
 
 /* Get xgethostname. */
 #include "xgethostname.h"
@@ -81,8 +81,7 @@ printtimefield (const char *fieldname, time_t t)
 static void
 printintfield (const char *fieldname, int num)
 {
-  char *p;
-  asprintf (&p, "%d (0x%x)", num, num);
+  char *p = xasprintf ("%d (0x%x)", num, num);
   printfield (fieldname, p);
   free (p);
 }
@@ -90,8 +89,7 @@ printintfield (const char *fieldname, int num)
 static void
 printuint32field (const char *fieldname, uint32_t num)
 {
-  char *p;
-  asprintf (&p, "%d (0x%x)", num, num);
+  char *p = xasprintf ("%d (0x%x)", num, num);
   printfield (fieldname, p);
   free (p);
 }
@@ -99,8 +97,7 @@ printuint32field (const char *fieldname, uint32_t num)
 static void
 print3field (const char *fieldname, const char *text, uint32_t num)
 {
-  char *p;
-  asprintf (&p, "%s (0x%x, %d)", text, num, num);
+  char *p = xasprintf ("%s (0x%x, %d)", text, num, num);
   printfield (fieldname, p);
   free (p);
 }
@@ -119,7 +116,7 @@ printdbkey (const char *realm, const char *principal, Shisa_key * dbkey)
       shishi_key_print (sh, stdout, key);
     }
   else
-    error (0, 0, "shishi_key_from_value failed (%d):\n%s",
+    error (0, 0, "shishi_key_from_value (%d):\n%s",
 	   rc, shishi_strerror (rc));
 }
 
@@ -134,7 +131,7 @@ dumplist_realm_principal (const char *realm, const char *principal)
       rc = shisa_principal_find (dbh, realm, principal, &ph);
       if (rc != SHISA_OK)
 	{
-	  error (0, 0, "shishi_principal_find failed (%d):\n%s",
+	  error (0, 0, "shishi_principal_find (%d):\n%s",
 		 rc, shisa_strerror (rc));
 	  return rc;
 	}
@@ -154,27 +151,28 @@ dumplist_realm_principal (const char *realm, const char *principal)
       size_t nkeys;
       size_t i;
 
-      printfield ("Account is", ph.isdisabled ? "DISABLED" : "enabled");
-      printuint32field ("Current key version", ph.kvno);
+      printfield (_("Account is"),
+		  ph.isdisabled ? _("DISABLED") : _("enabled"));
+      printuint32field (_("Current key version"), ph.kvno);
       if (ph.notusedbefore != (time_t) - 1)
-	printtimefield ("Account not valid before", ph.notusedbefore);
+	printtimefield (_("Account not valid before"), ph.notusedbefore);
       if (ph.lastinitialtgt != (time_t) - 1)
-	printtimefield ("Last initial TGT request at", ph.lastinitialtgt);
+	printtimefield (_("Last initial TGT request at"), ph.lastinitialtgt);
       if (ph.lastinitialrequest != (time_t) - 1)
-	printtimefield ("Last initial request at", ph.lastinitialrequest);
+	printtimefield (_("Last initial request at"), ph.lastinitialrequest);
       if (ph.lasttgt != (time_t) - 1)
-	printtimefield ("Last TGT request at", ph.lasttgt);
+	printtimefield (_("Last TGT request at"), ph.lasttgt);
       if (ph.lastrenewal != (time_t) - 1)
-	printtimefield ("Last ticket renewal at", ph.lastrenewal);
+	printtimefield (_("Last ticket renewal at"), ph.lastrenewal);
       if (ph.passwordexpire != (time_t) - 1)
-	printtimefield ("Password expire on", ph.passwordexpire);
+	printtimefield (_("Password expire on"), ph.passwordexpire);
       if (ph.accountexpire != (time_t) - 1)
-	printtimefield ("Account expire on", ph.accountexpire);
+	printtimefield (_("Account expire on"), ph.accountexpire);
 
       rc = shisa_keys_find (dbh, realm, principal, NULL, &keys, &nkeys);
       if (rc != SHISA_OK)
 	{
-	  error (0, 0, "shishi_keys_find(%s, %s) failed (%d):\n%s",
+	  error (0, 0, "shishi_keys_find(%s, %s) (%d):\n%s",
 		 realm, principal, rc, shisa_strerror (rc));
 	  return rc;
 	}
@@ -182,24 +180,24 @@ dumplist_realm_principal (const char *realm, const char *principal)
       for (i = 0; i < nkeys; i++)
 	if (keys[i])
 	  {
-	    printintfield ("Key", i);
+	    printintfield (_("Key"), i);
 
-	    print3field ("\tEtype", shishi_cipher_name (keys[i]->etype),
+	    print3field (_("\tEtype"), shishi_cipher_name (keys[i]->etype),
 			 keys[i]->etype);
 	    if (keys[i]->priority > 0)
-	      printintfield ("\tPriority", keys[i]->priority);
+	      printintfield (_("\tPriority"), keys[i]->priority);
 	    if (args.keys_given)
 	      printdbkey (realm, principal, keys[i]);
 	    if (keys[i]->saltlen > 0)
-	      printfield ("\tSalt", keys[i]->salt);
+	      printfield (_("\tSalt"), keys[i]->salt);
 	    if (keys[i]->str2keyparamlen > 0)
-	      printfield ("\tS2K params", keys[i]->str2keyparam);
+	      printfield (_("\tS2K params"), keys[i]->str2keyparam);
 	    if (args.keys_given)
 	      if (keys[i]->password)
-		printfield ("\tPassword", keys[i]->password);
+		printfield (_("\tPassword"), keys[i]->password);
 	  }
 	else
-	  printfield ("\tKey is", "MISSING");
+	  printfield (_("\tKey is"), _("MISSING"));
 
       shisa_keys_free (dbh, keys, nkeys);
     }
@@ -277,22 +275,22 @@ add (const char *realm, const char *principal,
   int rc;
 
   if (principal == NULL)
-    printf ("Adding realm `%s'...\n", realm);
+    printf (_("Adding realm `%s'...\n"), realm);
   else
-    printf ("Adding principal `%s@%s'...\n", principal, realm);
+    printf (_("Adding principal `%s@%s'...\n"), principal, realm);
 
   rc = shisa_principal_add (dbh, realm, principal, ph, key);
   if (rc != SHISA_OK)
-    error (EXIT_FAILURE, 0, "shisa_principal_add failed (%d):\n%s",
+    error (EXIT_FAILURE, 0, "shisa_principal_add (%d):\n%s",
 	   rc, shisa_strerror (rc));
 
   if (args.keys_given)
     printdbkey (realm, principal, key);
 
   if (principal == NULL)
-    printf ("Adding realm `%s'...done\n", realm);
+    printf (_("Adding realm `%s'...done\n"), realm);
   else
-    printf ("Adding principal `%s@%s'...done\n", principal, realm);
+    printf (_("Adding principal `%s@%s'...done\n"), principal, realm);
 }
 
 static void
@@ -308,7 +306,7 @@ delete (const char *realm, const char *principal)
 
       rc = shisa_enumerate_principals (dbh, realm, &principals, &nprincipals);
       if (rc != SHISA_OK)
-	error (EXIT_FAILURE, 0, "shisa_enumerate_principals failed (%d):\n%s",
+	error (EXIT_FAILURE, 0, "shisa_enumerate_principals (%d):\n%s",
 	       rc, shisa_strerror (rc));
 
       for (i = 0; i < nprincipals; i++)
@@ -323,19 +321,19 @@ delete (const char *realm, const char *principal)
     }
 
   if (principal == NULL)
-    printf ("Removing realm `%s'...\n", realm);
+    printf (_("Removing realm `%s'...\n"), realm);
   else
-    printf ("Removing principal `%s@%s'...\n", principal, realm);
+    printf (_("Removing principal `%s@%s'...\n"), principal, realm);
 
   rc = shisa_principal_remove (dbh, realm, principal);
   if (rc != SHISA_OK)
-    error (EXIT_FAILURE, 0, "shisa_principal_remove failed (%d):\n%s",
+    error (EXIT_FAILURE, 0, "shisa_principal_remove (%d):\n%s",
 	   rc, shisa_strerror (rc));
 
   if (principal == NULL)
-    printf ("Removing realm `%s'...done\n", realm);
+    printf (_("Removing realm `%s'...done\n"), realm);
   else
-    printf ("Removing principal `%s@%s'...done\n", principal, realm);
+    printf (_("Removing principal `%s@%s'...done\n"), principal, realm);
 }
 
 static void
@@ -362,12 +360,13 @@ apply_options (const char *realm,
 
       if (!salt && realm && principal)
 	{
-	  char *p;
-	  asprintf (&salt, "%s%s", realm, principal);
+	  char *name = xasprintf ("%s@%s", principal, realm);
 
-	  /* FIXME: Parse principal/realm and create proper salt. */
-	  while ((p = strchr (salt, '/')))
-	    memmove (p, p + 1, strlen (p));
+	  rc = shishi_derive_default_salt (sh, name, &salt);
+	  free (name);
+	  if (rc != SHISHI_OK)
+	    error (EXIT_FAILURE, 0, "shisa_derive_default_salt (%d):\n%s",
+		   rc, shisa_strerror (rc));
 	}
 
       if (args.string_to_key_parameter_given)
@@ -381,12 +380,12 @@ apply_options (const char *realm,
 	    {
 	      if (realm && principal)
 		rc = shishi_prompt_password (sh, &passwd,
-					     "Password for `%s@%s': ",
+					     _("Password for `%s@%s': "),
 					     principal, realm);
 	      else
-		rc = shishi_prompt_password (sh, &passwd, "Password: ");
+		rc = shishi_prompt_password (sh, &passwd, _("Password: "));
 	      if (rc != SHISHI_OK)
-		error (EXIT_FAILURE, 0, "Could not read password");
+		error (EXIT_FAILURE, 0, _("Could not read password"));
 	    }
 
 	  rc = shishi_key_from_string (sh, etype,
@@ -398,7 +397,7 @@ apply_options (const char *realm,
 	rc = shishi_key_random (sh, etype, &key);
 
       if (rc != SHISHI_OK)
-	error (EXIT_FAILURE, 0, "Could not create key (%d):\n%s",
+	error (EXIT_FAILURE, 0, _("Could not create key (%d):\n%s"),
 	       rc, shishi_strerror (rc));
 
       if (realm && principal)
@@ -423,7 +422,8 @@ apply_options (const char *realm,
 int
 main (int argc, char *argv[])
 {
-  char *realm = NULL, *principal = NULL;
+  const char *realm = NULL;
+  const char *principal = NULL;
   Shisa_principal ph;
   Shisa_key key;
   int rc;
@@ -434,7 +434,7 @@ main (int argc, char *argv[])
   set_program_name (argv[0]);
 
   if (cmdline_parser (argc, argv, &args) != 0)
-    error (EXIT_FAILURE, 0, "Try `%s --help' for more information.",
+    error (EXIT_FAILURE, 0, _("Try `%s --help' for more information."),
 	   program_name);
 
   rc = args.add_given + args.dump_given + args.list_given +
@@ -443,38 +443,38 @@ main (int argc, char *argv[])
 
   if (rc > 1 || args.inputs_num > 2)
     {
-      error (0, 0, "too many arguments");
-      error (EXIT_FAILURE, 0, "Try `%s --help' for more information.",
+      error (0, 0, _("too many arguments"));
+      error (EXIT_FAILURE, 0, _("Try `%s --help' for more information."),
 	     program_name);
     }
 
   if (rc == 0 || args.help_given)
     {
       cmdline_parser_print_help ();
-      printf ("\nMandatory arguments to long options are "
-	      "mandatory for short options too.\n\n");
-      printf ("Report bugs to <%s>.\n", PACKAGE_BUGREPORT);
+      printf (_("\nMandatory arguments to long options are "
+		"mandatory for short options too.\n\n"));
+      printf (_("Report bugs to <%s>.\n"), PACKAGE_BUGREPORT);
       return EXIT_SUCCESS;
     }
 
   rc = shisa_init_with_paths (&dbh, args.configuration_file_arg);
   if (rc != SHISA_OK)
-    error (EXIT_FAILURE, 0, "Initialization failed:\n%s",
+    error (EXIT_FAILURE, 0, _("Initialization failed:\n%s"),
 	   shisa_strerror (rc));
 
   rc = shisa_cfg (dbh, args.library_options_arg);
   if (rc != SHISA_OK)
-    error (EXIT_FAILURE, 0, "Could not read library options `%s':\n%s",
+    error (EXIT_FAILURE, 0, _("Could not read library options `%s':\n%s"),
 	   args.library_options_arg, shisa_strerror (rc));
 
   rc = shishi_init (&sh);
   if (rc != SHISHI_OK)
-    error (EXIT_FAILURE, 0, "Shishi initialization failed:\n%s",
+    error (EXIT_FAILURE, 0, _("Shishi initialization failed:\n%s"),
 	   shishi_strerror (rc));
 
   rc = shishi_cfg_clientkdcetype_set (sh, args.encryption_type_arg);
   if (rc != SHISHI_OK)
-    error (EXIT_FAILURE, 0, "Could not set encryption type `%s':\n%s",
+    error (EXIT_FAILURE, 0, _("Could not set encryption type `%s':\n%s"),
 	   args.encryption_type_arg, shishi_strerror (rc));
 
   if ((args.inputs_num < 2 && (args.modify_given ||
@@ -482,8 +482,8 @@ main (int argc, char *argv[])
 			       args.key_remove_given)) ||
       (args.inputs_num < 1 && (args.remove_given)))
     {
-      error (0, 0, "too few arguments");
-      error (0, 0, "Try `%s --help' for more information.", program_name);
+      error (0, 0, _("too few arguments"));
+      error (0, 0, _("Try `%s --help' for more information."), program_name);
       return EXIT_FAILURE;
     }
 
@@ -514,15 +514,15 @@ main (int argc, char *argv[])
 
       realm = shishi_realm_default (sh);
 
-      printf ("Adding default realm `%s'...\n", realm);
+      printf (_("Adding default realm `%s'...\n"), realm);
       add (realm, NULL, NULL, NULL);
 
-      asprintf (&tmp, "krbtgt/%s", realm);
+      tmp = xasprintf ("krbtgt/%s", realm);
       add (realm, tmp, &ph, &key);
       free (tmp);
 
       host = xgethostname ();
-      asprintf (&tmp, "host/%s", host);
+      tmp = xasprintf ("host/%s", host);
       free (host);
 
       memset (&key2, 0, sizeof (key2));
@@ -534,32 +534,32 @@ main (int argc, char *argv[])
     }
   else if (args.modify_given)
     {
-      printf ("Modifying principal `%s@%s'...\n", principal, realm);
+      printf (_("Modifying principal `%s@%s'...\n"), principal, realm);
 
       rc = shisa_principal_update (dbh, realm, principal, &ph);
       if (rc != SHISA_OK)
-	error (EXIT_FAILURE, 0, "shisa_principal_update failed (%d):\n%s",
+	error (EXIT_FAILURE, 0, "shisa_principal_update (%d):\n%s",
 	       rc, shisa_strerror (rc));
 
-      printf ("Modifying principal `%s@%s'...done\n", principal, realm);
+      printf (_("Modifying principal `%s@%s'...done\n"), principal, realm);
     }
   else if (args.key_add_given)
     {
-      printf ("Adding key to `%s@%s'...\n", principal, realm);
+      printf (_("Adding key to `%s@%s'...\n"), principal, realm);
 
       rc = shisa_key_add (dbh, realm, principal, &key);
       if (rc != SHISA_OK)
-	error (EXIT_FAILURE, 0, "shisa_key_add failed (%d):\n%s",
+	error (EXIT_FAILURE, 0, "shisa_key_add (%d):\n%s",
 	       rc, shisa_strerror (rc));
 
       if (args.keys_given)
 	printdbkey (realm, principal, &key);
 
-      printf ("Adding key to `%s@%s'...done\n", principal, realm);
+      printf (_("Adding key to `%s@%s'...done\n"), principal, realm);
     }
   else if (args.key_remove_given)
     {
-      printf ("Removing key from `%s@%s'...\n", principal, realm);
+      printf (_("Removing key from `%s@%s'...\n"), principal, realm);
 
       if (!args.password_given)
 	{
@@ -569,10 +569,10 @@ main (int argc, char *argv[])
 
       rc = shisa_key_remove (dbh, realm, principal, &key);
       if (rc != SHISA_OK)
-	error (EXIT_FAILURE, 0, "shisa_key_remove failed (%d):\n%s",
+	error (EXIT_FAILURE, 0, "shisa_key_remove (%d):\n%s",
 	       rc, shisa_strerror (rc));
 
-      printf ("Removing key from `%s@%s'...done\n", principal, realm);
+      printf (_("Removing key from `%s@%s'...done\n"), principal, realm);
     }
 
   shisa_done (dbh);
